# Chatsky Docker utils

## Description

This directory provides Docker files, necessary for deployment 
of various Chatsky utilities.

## Contents

* dockerfile_stats - Dockerfile for Chatsky statistics dashboard.
* entrypoint_stats.sh - Entrypoint script for Chatsky statistics dashboard.